==> spip_4.1.7+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Neistarten',
	'boxstr_close' => 'Zoumachen',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Weider',
	'boxstr_previous' => 'Zeréck',
	'boxstr_slideshowStart' => 'Diashow',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Gitt d’Elementer un déi d’Mediabox starten (CSS oder jQuery).',
	'explication_selecteur_galerie' => 'Gitt d’Elementer un déi sollen als Galerie gruppéiert ginn (CSS oder jQuery).',
	'explication_splash_url' => 'Gitt d’Url vum Element un dat soll automatesch an der Mediabox bei der éischter Visite vum ëffentleche Site gewise ginn.',
	'explication_traiter_toutes_images' => 'Eng Box bei all Biller asetzen?',

	// L
	'label_active' => 'D’Mediabox um ëffentleche Site aschalten',
	'label_apparence' => 'Layout',
	'label_aucun_style' => 'Ouni Default-Layout',
	'label_choix_transition_elastic' => 'Elastesch',
	'label_choix_transition_fade' => 'Iwwergang',
	'label_choix_transition_none' => 'Ouni Transitioun',
	'label_maxheight' => 'Maximal Héicht (% oder px)',
	'label_maxwidth' => 'Maximal Breet (% oder px)',
	'label_minheight' => 'Minimal Héicht (% oder px)',
	'label_minwidth' => 'Minimal Breet (% oder px)',
	'label_opacite' => 'Opacitéit vum Fong',
	'label_selecteur_commun' => 'Generell',
	'label_selecteur_galerie' => 'Galerie',
	'label_skin' => 'Layout',
	'label_slideshow_speed' => 'Zäit pro Foto an der Diashow (ms)',
	'label_speed' => 'Vitesse vum Iwwergang (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Héicht (% oder px)',
	'label_splash_url' => 'URL déi soll gewise ginn',
	'label_splash_width' => 'Breet (% oder px)',
	'label_traiter_toutes_images' => 'Biller',
	'label_transition' => 'Iwwergang tëschent 2 Biller',

	// T
	'titre_menu_box' => 'Mediabox',
	'titre_page_configurer_box' => 'Mediabox astellen'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_reinitialiser' => 'Neistarten',
	'boxstr_close' => 'Zoumachen',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Weider',
	'boxstr_previous' => 'Zeréck',
	'boxstr_slideshowStart' => 'Diashow',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Gitt d’Elementer un déi d’Mediabox starten (CSS oder jQuery).',
	'explication_selecteur_galerie' => 'Gitt d’Elementer un déi sollen als Galerie gruppéiert ginn (CSS oder jQuery).',
	'explication_splash_url' => 'Gitt d’Url vum Element un dat soll automatesch an der Mediabox bei der éischter Visite vum ëffentleche Site gewise ginn.',
	'explication_traiter_toutes_images' => 'Eng Box bei all Biller asetzen?',

	// L
	'label_active' => 'D’Mediabox um ëffentleche Site aschalten',
	'label_apparence' => 'Layout',
	'label_aucun_style' => 'Ouni Default-Layout',
	'label_choix_transition_elastic' => 'Elastesch',
	'label_choix_transition_fade' => 'Iwwergang',
	'label_choix_transition_none' => 'Ouni Transitioun',
	'label_maxheight' => 'Maximal Héicht (% oder px)',
	'label_maxwidth' => 'Maximal Breet (% oder px)',
	'label_minheight' => 'Minimal Héicht (% oder px)',
	'label_minwidth' => 'Minimal Breet (% oder px)',
	'label_opacite' => 'Opacitéit vum Fong',
	'label_selecteur_commun' => 'Generell',
	'label_selecteur_galerie' => 'Galerie',
	'label_skin' => 'Layout',
	'label_slideshow_speed' => 'Zäit pro Foto an der Diashow (ms)',
	'label_speed' => 'Vitesse vum Iwwergang (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Héicht (% oder px)',
	'label_splash_url' => 'URL déi soll gewise ginn',
	'label_splash_width' => 'Breet (% oder px)',
	'label_traiter_toutes_images' => 'Biller',
	'label_transition' => 'Iwwergang tëschent 2 Biller',

	// T
	'titre_menu_box' => 'Mediabox',
	'titre_page_configurer_box' => 'Mediabox astellen',
];
